==> qesteidutil-0.1.99.1586.tar.bz2: qesteidutil-0.1.99.1586/common/translations/common_et.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="et">
<defaultcodec></defaultcodec>
<context>
    <name>CertificateDialog</name>
    <message>
        <source>Save certificate</source>
        <translation>Salvesta sertifikaat</translation>
    </message>
    <message>
        <source>Failed to save file</source>
        <translation>Salvestamine ebaõnnestus</translation>
    </message>
    <message>
        <source>Certificate Information:</source>
        <translation>Sertifikaadi info:</translation>
    </message>
    <message>
        <source>This certificate is intended for following purpose(s):</source>
        <translation>Selle sertifikaadi otstarve on:</translation>
    </message>
    <message>
        <source>Issued to:</source>
        <translation>Kellele väljastatud:</translation>
    </message>
    <message>
        <source>Issued by:</source>
        <translation>Väljastaja:</translation>
    </message>
    <message>
        <source>Valid from</source>
        <translation>Kehtiv alates</translation>
    </message>
    <message>
        <source>to</source>
        <translation>kuni</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versioon</translation>
    </message>
    <message>
        <source>Serial number</source>
        <translation>Seeria number</translation>
    </message>
    <message>
        <source>Signature algorithm</source>
        <translation>Signatuuri algoritm</translation>
    </message>
    <message>
        <source>Issuer</source>
        <translation>Väljaandja</translation>
    </message>
    <message>
        <source>Vaild to</source>
        <translation>Kehtiv kuni</translation>
    </message>
    <message>
        <source>Subject</source>
        <translation>Subjekt</translation>
    </message>
    <message>
        <source>Public key</source>
        <translation>Avalik võti</translation>
    </message>
    <message>
        <source>Certificate policies</source>
        <translation>Sertifikaadi reeglid</translation>
    </message>
    <message>
        <source>Certificate</source>
        <translation>Sertifikaat</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Üldine</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detailid</translation>
    </message>
    <message>
        <source>Field</source>
        <translation>Väli</translation>
    </message>
    <message>
        <source>Value</source>
        <translation>Väärtus</translation>
    </message>
    <message>
        <source>Certification Path</source>
        <translation>Sertifitseermisahel</translation>
    </message>
    <message>
        <source>Certificate status:</source>
        <translation>Sertifikaadi staatus:</translation>
    </message>
    <message>
        <source>Certificates (*.cer *.crt *.pem)</source>
        <translation>Sertifikaadid (*.cer *.crt *.pem)</translation>
    </message>
    <message>
        <source>Enhanched key usage</source>
        <translation>Täiendatud võtme kasutus</translation>
    </message>
    <message>
        <source>Key usage</source>
        <translation>Võtme kasutus</translation>
    </message>
    <message>
        <source>Authority key identifier</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subject key identifier</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Common</name>
    <message>
        <source>Company</source>
        <translation>Asutus</translation>
    </message>
    <message>
        <source>Register code</source>
        <translation>Registrikood</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <source>Personal code</source>
        <translation>Isikukood</translation>
    </message>
    <message>
        <source>Card in reader</source>
        <translation>Lugejas on kaart</translation>
    </message>
    <message>
        <source>Auth certificate is</source>
        <translation>Isikutuvastuse sertifikaat on</translation>
    </message>
    <message>
        <source>Sign certificate is</source>
        <translation>Allkirjastamise sertifikaat on</translation>
    </message>
    <message>
        <source>valid</source>
        <translation>kehtiv</translation>
    </message>
    <message>
        <source>Your certificates will be expire</source>
        <translation>Sertifikaadid hakkavad aeguma</translation>
    </message>
    <message>
        <source>expired</source>
        <translation>aegunud</translation>
    </message>
    <message>
        <source>Open utility</source>
        <translation>Ava haldusvahend</translation>
    </message>
</context>
<context>
    <name>PinDialog</name>
    <message>
        <source>Selected action requires auth certificate.</source>
        <translation>Valitud tegevuse jaoks on vaja kasutada isikutuvastuse sertifikaati.</translation>
    </message>
    <message>
        <source>For using auth certificate enter PIN1</source>
        <translation>Sertifikaadi kasutamiseks sisesta PIN1</translation>
    </message>
    <message>
        <source>Selected action requires sign certificate.</source>
        <translation>Valitud tegevuse jaoks on vaja kasutada allkirja sertifikaati.</translation>
    </message>
    <message>
        <source>For using sign certificate enter PIN2</source>
        <translation>Sertifikaadi kasutamiseks sisesta PIN2</translation>
    </message>
    <message>
        <source>For using auth certificate enter PIN1 with pinpad</source>
        <translation>Sertifikaadi kasutamiseks sisesta PIN1 kaardilugeja sõrmistikult</translation>
    </message>
    <message>
        <source>For using sign certificate enter PIN2 with pinpad</source>
        <translation>Sertifikaadi kasutamiseks sisesta PIN2 kaardilugeja sõrmistikult</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Proves your identity to a remote computer</source>
        <translation>Tuvastab Teie isiksust arvuti kaugopereerimisel</translation>
    </message>
    <message>
        <source>Protects e-mail messages</source>
        <translation>Kaitseb e-mail sõnumeid</translation>
    </message>
    <message>
        <source>OCSP signing</source>
        <translation>OCSP allkirjastamine</translation>
    </message>
    <message>
        <source>All application policies</source>
        <translation>Kõik tarkvara poliisid</translation>
    </message>
    <message>
        <source>Digital signature</source>
        <translation>Digitaalne allkiri</translation>
    </message>
    <message>
        <source>Non repudiation</source>
        <translation>Tagasilükkamata</translation>
    </message>
    <message>
        <source>Key encipherment</source>
        <translation>Võti krüptimine</translation>
    </message>
    <message>
        <source>Data encipherment</source>
        <translation>Andmete krüptimine</translation>
    </message>
    <message>
        <source>Key agreement</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Key certificate sign</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CRL sign</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Encipher only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decipher only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>failed to load pkcs11 module</source>
        <translation>viga pkcs11 mooduli laadimisel</translation>
    </message>
    <message>
        <source>failed to list slots</source>
        <translation>viga pkcs11 slottide lugemisel</translation>
    </message>
    <message>
        <source>token failed</source>
        <translation>viga &quot;tokeni&quot; laadimisel</translation>
    </message>
    <message>
        <source>no token available</source>
        <translation>ei leitud ühtegi &quot;tokenit&quot;</translation>
    </message>
    <message>
        <source>no key matching certificate available</source>
        <translation>ei leitud ühtegi sobivat sertifikaati</translation>
    </message>
    <message>
        <source>Failed to connect to host. Are you connected to the internet?</source>
        <translation>Puudub internetiühendus!</translation>
    </message>
    <message>
        <source>no certificate available</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qesteidutil_0.3.1.orig.tar.bz2: qesteidutil-0.3.1/common/translations/common_et.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="et">
<context>
    <name>CertificateDialog</name>
    <message>
        <source>Save certificate</source>
        <translation>Salvesta sertifikaat</translation>
    </message>
    <message>
        <source>Failed to save file</source>
        <translation>Salvestamine ebaõnnestus</translation>
    </message>
    <message>
        <source>Certificate Information</source>
        <translation>Sertifikaadi info</translation>
    </message>
    <message>
        <source>This certificate is intended for following purpose(s):</source>
        <translation>Selle sertifikaadi otstarve on:</translation>
    </message>
    <message>
        <source>Issued to:</source>
        <translation>Kellele väljastatud:</translation>
    </message>
    <message>
        <source>Issued by:</source>
        <translation>Väljastaja:</translation>
    </message>
    <message>
        <source>Valid from</source>
        <translation>Kehtiv alates</translation>
    </message>
    <message>
        <source>to</source>
        <translation>kuni</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versioon</translation>
    </message>
    <message>
        <source>Serial number</source>
        <translation>Seeria number</translation>
    </message>
    <message>
        <source>Signature algorithm</source>
        <translation>Signatuuri algoritm</translation>
    </message>
    <message>
        <source>Issuer</source>
        <translation>Väljaandja</translation>
    </message>
    <message>
        <source>Vaild to</source>
        <translation>Kehtiv kuni</translation>
    </message>
    <message>
        <source>Subject</source>
        <translation>Subjekt</translation>
    </message>
    <message>
        <source>Public key</source>
        <translation>Avalik võti</translation>
    </message>
    <message>
        <source>Certificate policies</source>
        <translation>Sertifikaadi reeglid</translation>
    </message>
    <message>
        <source>Certificate</source>
        <translation>Sertifikaat</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Üldine</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detailid</translation>
    </message>
    <message>
        <source>Field</source>
        <translation>Väli</translation>
    </message>
    <message>
        <source>Value</source>
        <translation>Väärtus</translation>
    </message>
    <message>
        <source>Certification Path</source>
        <translation>Sertifitseermisahel</translation>
    </message>
    <message>
        <source>Certificate status:</source>
        <translation>Sertifikaadi staatus:</translation>
    </message>
    <message>
        <source>Certificates (*.cer *.crt *.pem)</source>
        <translation>Sertifikaadid (*.cer *.crt *.pem)</translation>
    </message>
    <message>
        <source>Enhanched key usage</source>
        <translation>Täiendatud võtme kasutus</translation>
    </message>
    <message>
        <source>Key usage</source>
        <translation>Võtme kasutus</translation>
    </message>
    <message>
        <source>Authority key identifier</source>
        <translation>Juurdepääsutõendi identifikaator</translation>
    </message>
    <message>
        <source>Subject key identifier</source>
        <translation>Objektivõtme identifikaator</translation>
    </message>
</context>
<context>
    <name>CheckConnection</name>
    <message>
        <source>Check proxy settings</source>
        <translation>Kontrolli proxy seadeid</translation>
    </message>
    <message>
        <source>Check proxy username and password</source>
        <translation>Kontrolli proxy kasutajanime ja parooli</translation>
    </message>
    <message>
        <source>Check internet connection</source>
        <translation>Kontrolli Interneti ühendust</translation>
    </message>
</context>
<context>
    <name>Common</name>
    <message>
        <source>Company</source>
        <translation>Asutus</translation>
    </message>
    <message>
        <source>Register code</source>
        <translation>Registrikood</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <source>Personal code</source>
        <translation>Isikukood</translation>
    </message>
    <message>
        <source>Card in reader</source>
        <translation>Lugejas on kaart</translation>
    </message>
    <message>
        <source>Auth certificate is</source>
        <translation>Isikutuvastuse sertifikaat on</translation>
    </message>
    <message>
        <source>Sign certificate is</source>
        <translation>Allkirjastamise sertifikaat on</translation>
    </message>
    <message>
        <source>valid</source>
        <translation>kehtiv</translation>
    </message>
    <message>
        <source>expired</source>
        <translation>aegunud</translation>
    </message>
    <message>
        <source>Open utility</source>
        <translation>Ava haldusvahend</translation>
    </message>
    <message>
        <source>Your certificates will expire soon</source>
        <translation>Sertifikaadid hakkavad aeguma</translation>
    </message>
</context>
<context>
    <name>PinDialog</name>
    <message>
        <source>Selected action requires auth certificate.</source>
        <translation>Valitud tegevuse jaoks on vaja kasutada isikutuvastuse sertifikaati.</translation>
    </message>
    <message>
        <source>For using auth certificate enter PIN1</source>
        <translation>Sertifikaadi kasutamiseks sisesta PIN1</translation>
    </message>
    <message>
        <source>Selected action requires sign certificate.</source>
        <translation>Valitud tegevuse jaoks on vaja kasutada allkirjastamise sertifikaati.</translation>
    </message>
    <message>
        <source>For using sign certificate enter PIN2</source>
        <translation>Sertifikaadi kasutamiseks sisesta PIN2</translation>
    </message>
    <message>
        <source>For using auth certificate enter PIN1 with pinpad</source>
        <translation>Sertifikaadi kasutamiseks sisesta PIN1 kaardilugeja sõrmistikult</translation>
    </message>
    <message>
        <source>For using sign certificate enter PIN2 with pinpad</source>
        <translation>Sertifikaadi kasutamiseks sisesta PIN2 kaardilugeja sõrmistikult</translation>
    </message>
</context>
<context>
    <name>SSLConnect</name>
    <message>
        <source>PIN canceled</source>
        <translation>PIN sisestamine katkestati</translation>
    </message>
    <message>
        <source>Invalid PIN</source>
        <translation>Vale PIN</translation>
    </message>
    <message>
        <source>failed to list slots</source>
        <translation>viga pkcs11 slottide lugemisel</translation>
    </message>
    <message>
        <source>token failed</source>
        <translation>viga &quot;tokeni&quot; laadimisel</translation>
    </message>
    <message>
        <source>no token available</source>
        <translation>ei leitud ühtegi &quot;tokenit&quot;</translation>
    </message>
    <message>
        <source>no certificate available</source>
        <translation>Ei ole kättesaadavaid sertifikaate</translation>
    </message>
    <message>
        <source>no key matching certificate available</source>
        <translation>ei leitud ühtegi sobivat sertifikaati</translation>
    </message>
    <message>
        <source>Failed to connect to host. Are you connected to the internet?</source>
        <translation>Puudub internetiühendus!</translation>
    </message>
    <message>
        <source>Pin locked</source>
        <translation>PIN on lukus</translation>
    </message>
    <message>
        <source>failed to load pkcs11 module &apos;%1&apos;</source>
        <translation>viga pkcs11 mooduli laadimisel &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Certificate is not valid</source>
        <translation>Sertifikaat ei ole kehtiv</translation>
    </message>
</context>
<context>
    <name>SslCertificate</name>
    <message>
        <source>All application policies</source>
        <translation>Kõik tarkvara poliisid</translation>
    </message>
    <message>
        <source>Proves your identity to a remote computer</source>
        <translation>Tuvastab sinu isiksust arvuti kaugopereerimisel</translation>
    </message>
    <message>
        <source>Protects e-mail messages</source>
        <translation>Kaitseb e-posti sõnumeid</translation>
    </message>
    <message>
        <source>OCSP signing</source>
        <translation>OCSP allkirjastamine</translation>
    </message>
    <message>
        <source>Digital signature</source>
        <translation>Digitaalne allkiri</translation>
    </message>
    <message>
        <source>Non repudiation</source>
        <translation>Salgamise vääramine</translation>
    </message>
    <message>
        <source>Key encipherment</source>
        <translation>Võtme krüptimine</translation>
    </message>
    <message>
        <source>Data encipherment</source>
        <translation>Andmete krüptimine</translation>
    </message>
    <message>
        <source>Key agreement</source>
        <translation>Aktsepteeritud võti</translation>
    </message>
    <message>
        <source>Key certificate sign</source>
        <translation>Võtme sertifikaadi allkiri</translation>
    </message>
    <message>
        <source>CRL sign</source>
        <translation>CRL allkiri</translation>
    </message>
    <message>
        <source>Encipher only</source>
        <translation>Ainult krüptimine</translation>
    </message>
    <message>
        <source>Decipher only</source>
        <translation>Ainult dekrüptimine</translation>
    </message>
</context>
</TS>
